@@ -19,8 +19,5 @@ test_that(desc="Mixed node levels object",{
   
   expect_silent(api_paths <- pxweb:::pxweb_test_create_api_paths(apis = pxweb_api_catalogue()))
   expect_true(all(c("http://api.scb.se/OV0104/v1/doris/en", 
-                    "http://api.scb.se/OV0104/v1/doris/sv", 
-                    "https://pxnet2.stat.fi/PXWeb/api/v1/en",
-                    "https://pxnet2.stat.fi/PXWeb/api/v1/fi",
-                    "https://pxnet2.stat.fi/PXWeb/api/v1/sv") %in% api_paths$paths))
+                    "http://api.scb.se/OV0104/v1/doris/sv") %in% api_paths$paths))
 })  
